@@ -112,7 +112,7 @@ type ReconcileHelmRelease struct {
 // Note:
 // The Controller will requeue the Request to be processed again if the returned error is non-nil or
 // Result.Requeue is true, otherwise upon completion it will remove the work from the queue.
-func (r *ReconcileHelmRelease) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+func (r *ReconcileHelmRelease) Reconcile(ctx context.Context, request reconcile.Request) (reconcile.Result, error) {
 	klog.V(1).Info("Reconciling HelmRelease: ", request.Namespace, "/", request.Name)
 
 	// Fetch the HelmRelease instance
@@ -163,18 +163,36 @@ func (r *ReconcileHelmRelease) Reconcile(request reconcile.Request) (reconcile.R
 	// handles the download of the chart as well
 	helmOperatorManagerFactory, err := r.newHelmOperatorManagerFactory(instance)
 	if err != nil {
-		klog.Error("Failed to create new HelmOperatorManagerFactory: ",
-			helmreleaseNsn(instance), " ", err)
+		altSourcePassed := false
 
-		instance.Status.SetCondition(appv1.HelmAppCondition{
-			Type:    appv1.ConditionIrreconcilable,
-			Status:  appv1.StatusTrue,
-			Reason:  appv1.ReasonReconcileError,
-			Message: err.Error(),
-		})
-		_ = r.updateResourceStatus(instance)
+		if instance.Repo.AltSource != nil {
+			klog.Warning("Attempting AltSource to create new HelmOperatorManagerFactory because Source failed: ",
+				helmreleaseNsn(instance), " ", err)
 
-		return reconcile.Result{RequeueAfter: time.Minute * 1}, nil
+			repoClone := instance.Repo.Clone()
+			instance.Repo = instance.Repo.AltSourceToSource()
+
+			helmOperatorManagerFactory, err = r.newHelmOperatorManagerFactory(instance)
+			if err == nil {
+				altSourcePassed = true
+				instance.Repo = repoClone
+			}
+		}
+
+		if !altSourcePassed {
+			klog.Error("Failed to create new HelmOperatorManagerFactory: ",
+				helmreleaseNsn(instance), " ", err)
+
+			instance.Status.SetCondition(appv1.HelmAppCondition{
+				Type:    appv1.ConditionIrreconcilable,
+				Status:  appv1.StatusTrue,
+				Reason:  appv1.ReasonReconcileError,
+				Message: err.Error(),
+			})
+			_ = r.updateResourceStatus(instance)
+
+			return reconcile.Result{RequeueAfter: time.Minute * 1}, nil
+		}
 	}
 
 	manager, err := r.newHelmOperatorManager(instance, request, helmOperatorManagerFactory)
@@ -506,7 +524,7 @@ func (r *ReconcileHelmRelease) uninstall(instance *appv1.HelmRelease, manager he
 
 	instance.Status.RemoveCondition(appv1.ConditionReleaseFailed)
 
-	caps, err := getCapabilities(manager.GetActionConfig())
+	caps, err := GetCapabilities(manager.GetActionConfig())
 	if err != nil {
 		klog.Error("Failed to get API Capabilities to perform cleanup check ", helmreleaseNsn(instance), " ", err)
 		r.updateUninstallResourceErrorStatus(instance, err)
